
/* Generated data (by glib-mkenums) */


/* --- bseexports.h --- */
#define BSE_TYPE_FILE_HANDLER_TYPE	    (BSE_TYPE_ID (BseFileHandlerType))
extern GType BSE_TYPE_ID (BseFileHandlerType);

/* --- bsebiquadfilter.h --- */
#define BSE_TYPE_BIQUAD_FILTER_TYPE	    (BSE_TYPE_ID (BseBiquadFilterType))
extern GType BSE_TYPE_ID (BseBiquadFilterType);
#define BSE_TYPE_BIQUAD_FILTER_NORM	    (BSE_TYPE_ID (BseBiquadFilterNorm))
extern GType BSE_TYPE_ID (BseBiquadFilterNorm);

/* --- bseenums.h --- */
#define BSE_TYPE_REGISTRATION_TYPE	    (BSE_TYPE_ID (BseRegistrationType))
extern GType BSE_TYPE_ID (BseRegistrationType);
#define BSE_TYPE_INTERPOL_TYPE	    (BSE_TYPE_ID (BseInterpolType))
extern GType BSE_TYPE_ID (BseInterpolType);
#define BSE_TYPE_LOOP_TYPE	    (BSE_TYPE_ID (BseLoopType))
extern GType BSE_TYPE_ID (BseLoopType);
#define BSE_TYPE_MAGIC_FLAGS	    (BSE_TYPE_ID (BseMagicFlags))
extern GType BSE_TYPE_ID (BseMagicFlags);
#define BSE_TYPE_USER_MSG_TYPE	    (BSE_TYPE_ID (BseUserMsgType))
extern GType BSE_TYPE_ID (BseUserMsgType);
#define BSE_TYPE_ERROR_TYPE	    (BSE_TYPE_ID (BseErrorType))
extern GType BSE_TYPE_ID (BseErrorType);

/* --- bseglobals.h --- */
#define BSE_TYPE_TIME_RANGE_TYPE	    (BSE_TYPE_ID (BseTimeRangeType))
extern GType BSE_TYPE_ID (BseTimeRangeType);

/* --- bsemidievent.h --- */
#define BSE_TYPE_MIDI_EVENT_TYPE	    (BSE_TYPE_ID (BseMidiEventType))
extern GType BSE_TYPE_ID (BseMidiEventType);
#define BSE_TYPE_MIDI_SIGNAL_TYPE	    (BSE_TYPE_ID (BseMidiSignalType))
extern GType BSE_TYPE_ID (BseMidiSignalType);

/* --- bseproject.h --- */
#define BSE_TYPE_PROJECT_STATE	    (BSE_TYPE_ID (BseProjectState))
extern GType BSE_TYPE_ID (BseProjectState);

/* --- bsessequencer.h --- */
#define BSE_TYPE_SSEQUENCER_JOB_TYPE	    (BSE_TYPE_ID (BseSSequencerJobType))
extern GType BSE_TYPE_ID (BseSSequencerJobType);

/* --- bsestandardosc.h --- */
#define BSE_TYPE_STANDARD_OSC_WAVE_TYPE	    (BSE_TYPE_ID (BseStandardOscWaveType))
extern GType BSE_TYPE_ID (BseStandardOscWaveType);

/* Generated data ends here */


/**
 ** Generated data (by mktypes.pl --externs)
 **/

/* --- bseamplifier.c --- */
extern GType bse_type_builtin_id_BseAmplifier;

/* --- bsebiquadfilter.c --- */
extern GType bse_type_builtin_id_BseBiquadFilter;

/* --- bseconstant.c --- */
extern GType bse_type_builtin_id_BseConstant;

/* --- bsecontainer.c --- */
extern GType bse_type_builtin_id_BseContainer;

/* --- bsecontextmerger.c --- */
extern GType bse_type_builtin_id_BseContextMerger;

/* --- bsedatapocket.c --- */
extern GType bse_type_builtin_id_BseDataPocket;

/* --- bseeditablesample.c --- */
extern GType bse_type_builtin_id_BseEditableSample;

/* --- bseitem.c --- */
extern GType bse_type_builtin_id_BseItem;

/* --- bsejanitor.c --- */
extern GType bse_type_builtin_id_BseJanitor;

/* --- bsemidiicontroller.c --- */
extern GType bse_type_builtin_id_BseMidiIController;

/* --- bsemididevice.c --- */
extern GType bse_type_builtin_id_BseMidiDevice;

/* --- bsemididevice-null.c --- */
extern GType bse_type_builtin_id_BseMidiDeviceNULL;

/* --- bsemididevice-oss.c --- */
extern GType bse_type_builtin_id_BseMidiDeviceOSS;

/* --- bsemidinotifier.c --- */
extern GType bse_type_builtin_id_BseMidiNotifier;

/* --- bsemidisynth.c --- */
extern GType bse_type_builtin_id_BseMidiSynth;

/* --- bseobject.c --- */
extern GType bse_type_builtin_id_BseObject;

/* --- bsepart.c --- */
extern GType bse_type_builtin_id_BsePart;

/* --- bsepcminput.c --- */
extern GType bse_type_builtin_id_BsePcmInput;

/* --- bsepcmoutput.c --- */
extern GType bse_type_builtin_id_BsePcmOutput;

/* --- bsepcmdevice.c --- */
extern GType bse_type_builtin_id_BsePcmDevice;

/* --- bsepcmdevice-oss.c --- */
extern GType bse_type_builtin_id_BsePcmDeviceOSS;

/* --- bseplugin.c --- */
extern GType bse_type_builtin_id_BsePlugin;

/* --- bseladspa.c --- */
extern GType bse_type_builtin_id_BseLadspaPlugin;

/* --- bseproject.c --- */
extern GType bse_type_builtin_id_BseProject;

/* --- bseserver.c --- */
extern GType bse_type_builtin_id_BseServer;

/* --- bsesnet.c --- */
extern GType bse_type_builtin_id_BseSNet;

/* --- bsesnooper.c --- */
extern GType bse_type_builtin_id_BseSnooper;

/* --- bsesong.c --- */
extern GType bse_type_builtin_id_BseSong;

/* --- bsesource.c --- */
extern GType bse_type_builtin_id_BseSource;

/* --- bsestandardosc.c --- */
extern GType bse_type_builtin_id_BseStandardOsc;

/* --- bsestorage.c --- */
extern GType bse_type_builtin_id_BseStorage;

/* --- bsesubinstrument.c --- */
extern GType bse_type_builtin_id_BseSubInstrument;

/* --- bsesubiport.c --- */
extern GType bse_type_builtin_id_BseSubIPort;

/* --- bsesubkeyboard.c --- */
extern GType bse_type_builtin_id_BseSubKeyboard;

/* --- bsesuboport.c --- */
extern GType bse_type_builtin_id_BseSubOPort;

/* --- bsesubsynth.c --- */
extern GType bse_type_builtin_id_BseSubSynth;

/* --- bsesuper.c --- */
extern GType bse_type_builtin_id_BseSuper;

/* --- bsetrack.c --- */
extern GType bse_type_builtin_id_BseTrack;

/* --- bsemidivoice.c --- */
extern GType bse_type_builtin_id_BseMidiVoiceInput;

/* --- bsemidivoice.c --- */
extern GType bse_type_builtin_id_BseMidiVoiceSwitch;

/* --- bsewave.c --- */
extern GType bse_type_builtin_id_BseWave;

/* --- bsewaveosc.c --- */
extern GType bse_type_builtin_id_BseWaveOsc;

/* --- bsecsynth.c --- */
extern GType bse_type_builtin_id_BseCSynth;

/* --- bsewaverepo.c --- */
extern GType bse_type_builtin_id_BseWaveRepo;

/* --- bseladspamodule.c --- */
extern GType bse_type_builtin_id_BseLadspaModule;

/* --- bsepcmwriter.c --- */
extern GType bse_type_builtin_id_BsePcmWriter;

/**
 ** Generated data ends here
 **/

/*-------- begin ../sfi/sfidl generated code --------*/



typedef struct _BseIntSeq BseIntSeq;
typedef struct _BseNoteSeq BseNoteSeq;
typedef struct _BseStringSeq BseStringSeq;
typedef struct _BseProxySeq BseProxySeq;
typedef struct _BsePartNoteSeq BsePartNoteSeq;
typedef struct _BseCategorySeq BseCategorySeq;
typedef struct _BseDotSeq BseDotSeq;
typedef struct _BseTrackPartSeq BseTrackPartSeq;
typedef struct _BsePartNote BsePartNote;
typedef struct _BseNoteDescription BseNoteDescription;
typedef struct _BseNoteSequence BseNoteSequence;
typedef struct _BseIcon BseIcon;
typedef struct _BseCategory BseCategory;
typedef struct _BseDot BseDot;
typedef struct _BseTrackPart BseTrackPart;
typedef struct _BseSongTiming BseSongTiming;
typedef struct _BseSampleFileInfo BseSampleFileInfo;
typedef struct _BseGConfig BseGConfig;

struct _BseIntSeq {
  guint n_ints;
  SfiInt* ints;
};
struct _BseNoteSeq {
  guint n_notes;
  SfiInt* notes;
};
struct _BseStringSeq {
  guint n_strings;
  gchar** strings;
};
struct _BseProxySeq {
  guint n_proxies;
  SfiProxy* proxies;
};
struct _BsePartNoteSeq {
  guint n_pnotes;
  BsePartNote** pnotes;
};
struct _BseCategorySeq {
  guint n_cats;
  BseCategory** cats;
};
struct _BseDotSeq {
  guint n_dots;
  BseDot** dots;
};
struct _BseTrackPartSeq {
  guint n_tparts;
  BseTrackPart** tparts;
};
struct _BsePartNote {
  SfiInt id;
  SfiInt tick;
  SfiInt duration;
  SfiInt note;
  SfiInt fine_tune;
  SfiReal velocity;
  SfiBool selected;
};
struct _BseNoteDescription {
  SfiInt note;
  SfiInt octave;
  SfiReal freq;
  SfiInt fine_tune;
  SfiInt semitone;
  SfiBool upshift;
  SfiInt letter;
  gchar* name;
  SfiInt max_fine_tune;
  SfiInt kammer_note;
};
struct _BseNoteSequence {
  SfiInt offset;
  BseNoteSeq* notes;
};
struct _BseIcon {
  SfiInt bytes_per_pixel;
  SfiInt width;
  SfiInt height;
  SfiBBlock* pixels;
};
struct _BseCategory {
  SfiInt category_id;
  gchar* category;
  SfiInt mindex;
  SfiInt lindex;
  gchar* type;
  BseIcon* icon;
};
struct _BseDot {
  SfiReal x;
  SfiReal y;
};
struct _BseTrackPart {
  SfiInt tick;
  SfiProxy part;
  SfiInt duration;
};
struct _BseSongTiming {
  SfiInt tick;
  SfiReal bpm;
  SfiInt nominator;
  SfiInt denominator;
  SfiInt tpqn;
  SfiInt tpt;
};
struct _BseSampleFileInfo {
  gchar* file;
  SfiInt size;
  SfiNum mtime;
  gchar* loader;
  BseStringSeq* waves;
  SfiInt error;
};
struct _BseGConfig {
  SfiInt synth_block_size;
  SfiInt synth_mixing_freq;
  SfiBool invert_sustain;
  SfiReal step_volume_dB;
  SfiInt step_bpm;
};

BseIntSeq* bse_int_seq_new (void);
void bse_int_seq_append (BseIntSeq* seq, SfiInt element);
BseIntSeq* bse_int_seq_copy_shallow (BseIntSeq* seq);
BseIntSeq* bse_int_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_int_seq_to_seq (BseIntSeq* seq);
void bse_int_seq_resize (BseIntSeq* seq, guint new_size);
void bse_int_seq_free (BseIntSeq* seq);

BseNoteSeq* bse_note_seq_new (void);
void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
BseNoteSeq* bse_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
void bse_note_seq_free (BseNoteSeq* seq);

BseStringSeq* bse_string_seq_new (void);
void bse_string_seq_append (BseStringSeq* seq, const gchar* element);
BseStringSeq* bse_string_seq_copy_shallow (BseStringSeq* seq);
BseStringSeq* bse_string_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
void bse_string_seq_free (BseStringSeq* seq);

BseProxySeq* bse_proxy_seq_new (void);
void bse_proxy_seq_append (BseProxySeq* seq, SfiProxy element);
BseProxySeq* bse_proxy_seq_copy_shallow (BseProxySeq* seq);
BseProxySeq* bse_proxy_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_proxy_seq_to_seq (BseProxySeq* seq);
void bse_proxy_seq_resize (BseProxySeq* seq, guint new_size);
void bse_proxy_seq_free (BseProxySeq* seq);

BsePartNoteSeq* bse_part_note_seq_new (void);
void bse_part_note_seq_append (BsePartNoteSeq* seq, BsePartNote* element);
BsePartNoteSeq* bse_part_note_seq_copy_shallow (BsePartNoteSeq* seq);
BsePartNoteSeq* bse_part_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_part_note_seq_to_seq (BsePartNoteSeq* seq);
void bse_part_note_seq_resize (BsePartNoteSeq* seq, guint new_size);
void bse_part_note_seq_free (BsePartNoteSeq* seq);

BseCategorySeq* bse_category_seq_new (void);
void bse_category_seq_append (BseCategorySeq* seq, BseCategory* element);
BseCategorySeq* bse_category_seq_copy_shallow (BseCategorySeq* seq);
BseCategorySeq* bse_category_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_category_seq_to_seq (BseCategorySeq* seq);
void bse_category_seq_resize (BseCategorySeq* seq, guint new_size);
void bse_category_seq_free (BseCategorySeq* seq);

BseDotSeq* bse_dot_seq_new (void);
void bse_dot_seq_append (BseDotSeq* seq, BseDot* element);
BseDotSeq* bse_dot_seq_copy_shallow (BseDotSeq* seq);
BseDotSeq* bse_dot_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_dot_seq_to_seq (BseDotSeq* seq);
void bse_dot_seq_resize (BseDotSeq* seq, guint new_size);
void bse_dot_seq_free (BseDotSeq* seq);

BseTrackPartSeq* bse_track_part_seq_new (void);
void bse_track_part_seq_append (BseTrackPartSeq* seq, BseTrackPart* element);
BseTrackPartSeq* bse_track_part_seq_copy_shallow (BseTrackPartSeq* seq);
BseTrackPartSeq* bse_track_part_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
void bse_track_part_seq_free (BseTrackPartSeq* seq);

BsePartNote* bse_part_note_new (void);
BsePartNote* bse_part_note_copy_shallow (BsePartNote* rec);
BsePartNote* bse_part_note_from_rec (SfiRec *sfi_rec);
SfiRec *bse_part_note_to_rec (BsePartNote* rec);
void bse_part_note_free (BsePartNote* rec);

BseNoteDescription* bse_note_description_new (void);
BseNoteDescription* bse_note_description_copy_shallow (BseNoteDescription* rec);
BseNoteDescription* bse_note_description_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_description_to_rec (BseNoteDescription* rec);
void bse_note_description_free (BseNoteDescription* rec);

BseNoteSequence* bse_note_sequence_new (void);
BseNoteSequence* bse_note_sequence_copy_shallow (BseNoteSequence* rec);
BseNoteSequence* bse_note_sequence_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_sequence_to_rec (BseNoteSequence* rec);
void bse_note_sequence_free (BseNoteSequence* rec);

BseIcon* bse_icon_new (void);
BseIcon* bse_icon_copy_shallow (BseIcon* rec);
BseIcon* bse_icon_from_rec (SfiRec *sfi_rec);
SfiRec *bse_icon_to_rec (BseIcon* rec);
void bse_icon_free (BseIcon* rec);

BseCategory* bse_category_new (void);
BseCategory* bse_category_copy_shallow (BseCategory* rec);
BseCategory* bse_category_from_rec (SfiRec *sfi_rec);
SfiRec *bse_category_to_rec (BseCategory* rec);
void bse_category_free (BseCategory* rec);

BseDot* bse_dot_new (void);
BseDot* bse_dot_copy_shallow (BseDot* rec);
BseDot* bse_dot_from_rec (SfiRec *sfi_rec);
SfiRec *bse_dot_to_rec (BseDot* rec);
void bse_dot_free (BseDot* rec);

BseTrackPart* bse_track_part_new (void);
BseTrackPart* bse_track_part_copy_shallow (BseTrackPart* rec);
BseTrackPart* bse_track_part_from_rec (SfiRec *sfi_rec);
SfiRec *bse_track_part_to_rec (BseTrackPart* rec);
void bse_track_part_free (BseTrackPart* rec);

BseSongTiming* bse_song_timing_new (void);
BseSongTiming* bse_song_timing_copy_shallow (BseSongTiming* rec);
BseSongTiming* bse_song_timing_from_rec (SfiRec *sfi_rec);
SfiRec *bse_song_timing_to_rec (BseSongTiming* rec);
void bse_song_timing_free (BseSongTiming* rec);

BseSampleFileInfo* bse_sample_file_info_new (void);
BseSampleFileInfo* bse_sample_file_info_copy_shallow (BseSampleFileInfo* rec);
BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
void bse_sample_file_info_free (BseSampleFileInfo* rec);

BseGConfig* bse_gconfig_new (void);
BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
SfiRec *bse_gconfig_to_rec (BseGConfig* rec);
void bse_gconfig_free (BseGConfig* rec);


extern SfiRecFields bse_part_note_fields;
extern GType BSE_TYPE_PART_NOTE;
extern SfiRecFields bse_note_description_fields;
extern GType BSE_TYPE_NOTE_DESCRIPTION;
extern SfiRecFields bse_note_sequence_fields;
extern GType BSE_TYPE_NOTE_SEQUENCE;
extern SfiRecFields bse_icon_fields;
extern GType BSE_TYPE_ICON;
extern SfiRecFields bse_category_fields;
extern GType BSE_TYPE_CATEGORY;
extern SfiRecFields bse_dot_fields;
extern GType BSE_TYPE_DOT;
extern SfiRecFields bse_track_part_fields;
extern GType BSE_TYPE_TRACK_PART;
extern SfiRecFields bse_song_timing_fields;
extern GType BSE_TYPE_SONG_TIMING;
extern SfiRecFields bse_sample_file_info_fields;
extern GType BSE_TYPE_SAMPLE_FILE_INFO;
extern SfiRecFields bse_gconfig_fields;
extern GType BSE_TYPE_GCONFIG;
extern GType BSE_TYPE_INT_SEQ;
extern GType BSE_TYPE_NOTE_SEQ;
extern GType BSE_TYPE_STRING_SEQ;
extern GType BSE_TYPE_PROXY_SEQ;
extern GType BSE_TYPE_PART_NOTE_SEQ;
extern GType BSE_TYPE_CATEGORY_SEQ;
extern GType BSE_TYPE_DOT_SEQ;
extern GType BSE_TYPE_TRACK_PART_SEQ;



/*-------- end ../sfi/sfidl generated code --------*/


